@@ -358,6 +358,15 @@ class TestFinvoiceWrapperWithPulliFinvoice(FinvoiceTestCase):
         invoice = self.wrapper.invoice
         self.assertEqual(invoice.payment_overdue_text, u'Viivästyskorko 16%')
 
+    def test_invoice_terms_of_payment(self):
+        """
+        test_invoice_terms_of_payment
+
+        """
+        invoice = self.wrapper.invoice
+        self.assertEqual(invoice.terms_of_payment, (u'5 pävää ./.2%,'
+                                                    u' 14 päivää netto'))
+
     def test_invoice_typecode(self):
         """
         test_invoice_typecode
