@@ -54,6 +54,7 @@ class Invoice(object):
     total_untaxed_currency = None
     vat_amount_currency = None
     free_text = None
+    terms_of_payment = None
     payment_overdue_text = None
     payment_overdue_percent = None
     typecode = None
@@ -90,6 +91,9 @@ class Invoice(object):
 
             payment_details = invoice_details[0].PaymentTermsDetailsSet
             if len(payment_details) > 0:
+                terms = payment_details[0].PaymentTermsFreeTextSet
+                if len(terms)>0 and terms[0].text:
+                    self.terms_of_payment = terms[0].text
                 due_date = payment_details[0].InvoiceDueDateSet
                 if len(due_date) > 0:
                     if due_date[0].text:
